pub struct IdentWraper(/* private fields */);Expand description
A newtype wrapper around an identifier that implements Parse to consume
an identifier from the input stream regardless of keyword status.