pub fn parse_error<T: ToTokens>(tokens: T, message: &str) -> TokenStreamExpand description
Produces a compile_error! token stream spanned over tokens,
reporting message at the location of the offending tokens.
pub fn parse_error<T: ToTokens>(tokens: T, message: &str) -> TokenStreamProduces a compile_error! token stream spanned over tokens,
reporting message at the location of the offending tokens.